repo stringclasses 15
values | fix_commit stringlengths 40 40 | buggy_commit stringlengths 40 40 | message stringlengths 3 64.3k | files listlengths 1 300 | timestamp timestamp[s]date 2013-03-13 20:45:00 2026-04-11 07:48:46 |
|---|---|---|---|---|---|
ollama/ollama | f2044b5838b867272417130c618e36809aa72b9d | d53988f6195e4e1afbe17f64d2966209e48d7152 | web: fix newsletter signup | [
{
"path": "web/app/api/signup/route.ts",
"patch": "@@ -6,12 +6,22 @@ const analytics = new Analytics({ writeKey: process.env.TELEMETRY_WRITE_KEY || '\n export async function POST(req: Request) {\n const { email } = await req.json()\n \n- analytics.identify({\n- anonymousId: uuid(),\n+ const id = uuid... | 2023-07-19T23:11:56 |
huggingface/transformers | 1c8f206ecc31c3a9aa7e515f668c262d6939867d | 3016717f0d904910fd9a55b3708e76024e71fe72 | Fix pylint warnings (#41222)
* Remove unused variables
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
* Remove reimported packages
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
* Fix code
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
* Fix pylint warnings
Signed-off-by: Yuanyuan Chen <cyyever@outl... | [
{
"path": "src/transformers/__init__.py",
"patch": "@@ -770,7 +770,6 @@\n from .utils import is_torch_npu_available as is_torch_npu_available\n from .utils import is_torch_xla_available as is_torch_xla_available\n from .utils import is_torch_xpu_available as is_torch_xpu_available\n- from .ut... | 2025-10-01T13:16:22 |
denoland/deno | 62e63ac9cacd6f55d5999c17814ef2d842213b5f | 746f60d2a4eda1b825d7d459de192ee416dbc015 | fix(audit): remove unwrap in favor of log, don't print empty reports (#31479)
Changes to print reports from socket.dev, only if something is found. | [
{
"path": "cli/tools/pm/audit.rs",
"patch": "@@ -663,10 +663,14 @@ mod socket_dev {\n None\n }\n })\n- .map(|json_response| {\n- let response: FirewallResponse =\n- serde_json::from_str(&json_response).unwrap();\n- response\n+ .filter_map(|json_respon... | 2025-12-02T23:30:57 |
ggml-org/llama.cpp | 704d90c987cdf00751567b2088c4e54742aa2d3f | 360d6533db39e11577afe9b0aece20c6b5ddaf1f | Revert "sycl: add usage of enqueue_functions extension (#14244)" (#15910)
* Revert "sycl: add usage of enqueue_functions extension (#14244)"
This reverts commit 8308f98c7fb778e54bf75538f5234d8bd20915e9.
* fix missed revert code, format the code | [
{
"path": "ggml/src/ggml-sycl/binbcast.cpp",
"patch": "@@ -225,9 +225,9 @@ struct bin_bcast_sycl {\n dpct::has_capability_or_fail(stream->get_device(),\n {sycl::aspect::fp16});\n \n- sycl_parallel_for(\n- ... | 2025-09-12T01:15:12 |
ollama/ollama | 10d502611fc815a9559b5baa8817d23551db8a91 | 7fe4103b946e8ee7a9ed834bbd6d1c274d480022 | fix discord link in `README.md` | [
{
"path": "README.md",
"patch": "@@ -7,7 +7,7 @@\n \n # Ollama\n \n-\n+[](https://discord.gg/ollama)\n \n Create, run, and share large language mode... | 2023-07-19T19:31:48 |
vuejs/vue | 1bcc571739d7228db0bc947ee67c20dde5aeb7e0 | eb601adb6d907bc2d22202ad6242b6969f95db3d | Revert "fix #4041, warn overriding Vue's internal methods (#4111)"
This reverts commit 4078ce9c58830fecff095ab96dc41693377794dd. | [
{
"path": "src/core/instance/state.js",
"patch": "@@ -21,8 +21,6 @@ import {\n noop\n } from '../util/index'\n \n-import BuiltinVue from '../index'\n-\n export function initState (vm: Component) {\n vm._watchers = []\n initProps(vm)\n@@ -145,16 +143,12 @@ function initMethods (vm: Component) {\n if ... | 2016-11-09T21:06:29 |
huggingface/transformers | 3016717f0d904910fd9a55b3708e76024e71fe72 | ca975f1cb880d86dd7d85485c236b8bebad57273 | Use removeprefix and removesuffix (#41240)
* Use removeprefix and removesuffix
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
* More fixes
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
---------
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> | [
{
"path": "src/transformers/commands/chat.py",
"patch": "@@ -443,8 +443,7 @@ def parse_generate_flags(self, generate_flags: list[str]) -> dict:\n # 2. b. strings should be quoted\n def is_number(s: str) -> bool:\n # handle negative numbers\n- if s.startswith(\"-\"):\n-... | 2025-10-01T13:13:04 |
denoland/deno | 746f60d2a4eda1b825d7d459de192ee416dbc015 | 6b78b55a9aad141b397768b5f8dc8b454a962189 | fix(tsgo): do not error out on non js/ts imports from npm packages (#31478)
Fixes #31423
This already worked for non npm files because the loading for non-npm
files uses the module graph, and things like CSS don't appear in the
module graph. That meant we weren't prompting tsc to create a source
file and parse those... | [
{
"path": "cli/tsc/go.rs",
"patch": "@@ -662,6 +662,33 @@ fn load_inner(\n let is_cjs = result.is_cjs;\n let media_type = result.media_type;\n \n+ match media_type {\n+ MediaType::JavaScript\n+ | MediaType::Jsx\n+ | MediaType::Mjs\n+ | MediaType::Cjs\n+ | MediaType::TypeScript\n+ | Me... | 2025-12-02T22:06:15 |
ggml-org/llama.cpp | 0e6ff0046f4a2983b2c77950aa75960fe4b4f0e2 | df082f56309073ecf885eceaa21b86e8a487e61b | CUDA: larger SRAM reads for tile FA, AMD FP16 dot (#15927)
* CUDA: larger SRAM reads for tile FA, AMD FP16 dot
* fix logic for availability of v_dot2_f32_f16 | [
{
"path": "ggml/src/ggml-cuda/common.cuh",
"patch": "@@ -555,7 +555,7 @@ static __device__ __forceinline__ void ggml_cuda_mad(float & acc, const float2 v\n }\n \n static __device__ __forceinline__ void ggml_cuda_mad(float & acc, const half2 v, const half2 u) {\n-#if defined(GGML_USE_HIP) && defined(GCN)\n+#... | 2025-09-11T19:19:58 |
ollama/ollama | f08c050e578101de11723fd797f15773bb8c4b89 | 4ca7c4be1fc0aeca41587ff6c74dd27e12ff54c7 | fix page transitions flickering | [
{
"path": "web/app/download/page.tsx",
"patch": "@@ -1,3 +1,5 @@\n+import Image from 'next/image'\n+\n import Header from '../header'\n import Downloader from './downloader'\n import Signup from './signup'\n@@ -30,7 +32,7 @@ export default async function Download() {\n <>\n <Header />\n <mai... | 2023-07-19T14:19:24 |
huggingface/transformers | 1d1ac078933dc7eb902a4d49b9eb347e5242d1e6 | bcec3e2175ab7360fd8caa6ffc89682714718563 | [repo utils] Update `models_to_deprecate.py` (#41231)
* update models_to_deprecate
* exclude this file
* handle typos and aliases
* don't commit files
* PR suggestions; make fixup | [
{
"path": "utils/models_to_deprecate.py",
"patch": "@@ -12,7 +12,8 @@\n # See the License for the specific language governing permissions and\n # limitations under the License.\n \"\"\"\n-Script to find a candidate list of models to deprecate based on the number of downloads and the date of the last commit.... | 2025-10-01T12:01:52 |
vuejs/vue | eb601adb6d907bc2d22202ad6242b6969f95db3d | 40c85f79a5520b7c87955752efe7fb9c93dd48fe | fixed deps and README for the 2 packages about weex (#4160) | [
{
"path": "packages/weex-template-compiler/README.md",
"patch": "@@ -1,3 +1,3 @@\n # weex-template-compiler\n \n-> This package is auto-generated. For pull requests please see [src/entries/weex-compiler.js](https://github.com/weexteam/weex-vue-framework/blob/dev-weex/src/entries/weex-compiler.js).\n+> This ... | 2016-11-09T02:39:59 |
denoland/deno | 57be16042c7ba21efa0c37f887f1f4b0923d0db2 | 0d662fee33071c797f9aa8ef9a095d75cb5733cb | chore: speed up macos compile tests (#31477)
Most of the tests for deno compile take >= 20 seconds (each) on macos.
This is mostly due to sha2 and libsui taking a long time to process the
debug binary. This speeds them up to <1 sec each, which saves multiple
minutes when running all the tests | [
{
"path": "Cargo.toml",
"patch": "@@ -427,6 +427,13 @@ opt-level = 3\n [profile.dev.package.v8]\n opt-level = 1\n \n+# speeds up deno compile tests a lot\n+[profile.dev.package.libsui]\n+opt-level = 3\n+\n+[profile.dev.package.sha2]\n+opt-level = 3\n+\n [profile.release.package.async-compression]\n opt-leve... | 2025-12-02T21:35:36 |
ggml-org/llama.cpp | df082f56309073ecf885eceaa21b86e8a487e61b | 24a6734daf6932ff29ba8c1ff0245c51d76f783e | nitpick : correct MB to MiB (#15934)
MB was incorrectly used for 1024 x 1024 bytes instead of MiB | [
{
"path": "src/llama-quant.cpp",
"patch": "@@ -920,7 +920,7 @@ static void llama_model_quantize_impl(const std::string & fname_inp, const std::\n new_type = tensor->type;\n new_data = tensor->data;\n new_size = ggml_nbytes(tensor);\n- LLAMA_LOG_INFO(\"size = %8... | 2025-09-11T17:12:34 |
vuejs/vue | 2f63cc8a142f9045b78571432df384a551363c35 | c4252d3f174653fa9b15c96d864fd9ab47620606 | fix eslint | [
{
"path": ".eslintrc",
"patch": "@@ -4,6 +4,7 @@\n \"extends\": \"vue\",\n \"plugins\": [\"flowtype\"],\n \"rules\": {\n+ \"no-useless-escape\": 0,\n \"flowtype/define-flow-type\": 1,\n \"flowtype/use-flow-type\": 1\n }",
"additions": 1,
"deletions": 0,
"language": "Unknown"
... | 2016-11-07T22:31:25 |
huggingface/transformers | bcec3e2175ab7360fd8caa6ffc89682714718563 | ae879f67f892f64f41a70c59b4136721f37fcca0 | fix TrainerIntegrationDeepSpeed UT failures (#41236)
Signed-off-by: Yao, Matrix <matrix.yao@intel.com> | [
{
"path": "src/transformers/integrations/deepspeed.py",
"patch": "@@ -356,7 +356,7 @@ def deepspeed_optim_sched(trainer, hf_deepspeed_config, args, num_training_steps\n \n optimizer = None\n if \"optimizer\" in config:\n- if args.adafactor:\n+ if args.optim == \"adafactor\":\n ... | 2025-10-01T11:55:01 |
denoland/deno | 0d662fee33071c797f9aa8ef9a095d75cb5733cb | cafd7f6c7f646b18f51bf3bc3156efa3d2000d48 | fix(test): Remove ANSI Escape Codes for Junit Reports (#30854)
* Add an option to the report printer to not use ansi codes.
* Made this default fore the junit file output.
* Implemented removal of codes in the formatter.
It would be preferable for performance to not include them in the first
place but that change is ... | [
{
"path": "cli/tools/test/fmt.rs",
"patch": "@@ -3,6 +3,7 @@\n use std::borrow::Cow;\n use std::ops::AddAssign;\n \n+use console_static_text::ansi::strip_ansi_codes;\n use deno_core::stats::RuntimeActivity;\n use deno_core::stats::RuntimeActivityDiff;\n use deno_core::stats::RuntimeActivityTrace;\n@@ -88,10... | 2025-12-02T17:11:44 |
ggml-org/llama.cpp | 24a6734daf6932ff29ba8c1ff0245c51d76f783e | 2b3efea9a4d91216850856fbb77075db26f6a6eb | ggml-cpu : add check for ARM MATMUL_INT8/i8mm support (#15922)
This commit adds a check for GGML_MACHINE_SUPPORTS_i8mm when enabling
MATMUL_INT8 features, ensuring that i8mm intrinsics are only used when
the target hardware actually supports them.
The motivation for this is to fix ggml CI build failures where the
fea... | [
{
"path": "ggml/src/ggml-cpu/CMakeLists.txt",
"patch": "@@ -224,7 +224,13 @@ function(ggml_add_cpu_backend_variant_impl tag_name)\n foreach(feature DOTPROD SVE MATMUL_INT8 FMA FP16_VECTOR_ARITHMETIC SME)\n string(FIND \"${ARM_FEATURE}\" \"__ARM_FEATURE_${feature} 1\" feat... | 2025-09-11T13:39:12 |
ollama/ollama | 68df36ae509e5e2ad5909b810f5a263b0a54cd46 | 6e36f948df22beed4ced79c3a75f168978df6163 | fix pull 0 bytes on completed layer | [
{
"path": "api/client.go",
"patch": "@@ -160,11 +160,11 @@ func (c *Client) Generate(ctx context.Context, req *GenerateRequest, fn Generate\n \t})\n }\n \n-type PullProgressFunc func(PullProgress) error\n+type PullProgressFunc func(ProgressResponse) error\n \n func (c *Client) Pull(ctx context.Context, req ... | 2023-07-19T01:51:30 |
vuejs/vue | c4252d3f174653fa9b15c96d864fd9ab47620606 | ff551029bf872ad067ac7c5ba7c6311fdde7c674 | fix weex merge flow types | [
{
"path": "src/entries/weex-compiler.js",
"patch": "@@ -11,9 +11,10 @@ export function compile (\n options = options || {}\n const errors = []\n // allow injecting modules/directives\n+ const baseModules = baseOptions.modules || []\n const modules = options.modules\n- ? baseOptions.modules.conca... | 2016-11-07T22:27:46 |
ggml-org/llama.cpp | 2b3efea9a4d91216850856fbb77075db26f6a6eb | c0389dba43d50695f9d3f57dd1f1a14cbefc100c | kleidiai: fix GGML_ASSERT(*cur_backend_id != -1) failed (#15614)
* kleidiai: fix GGML_ASSERT(*cur_backend_id != -1) failed
* removes the Whisper-specific check for GET_ROWS support | [
{
"path": "ggml/src/ggml-cpu/kleidiai/kleidiai.cpp",
"patch": "@@ -515,9 +515,6 @@ class extra_buffer_type : ggml::cpu::extra_buffer_type {\n op->src[0]->buffer &&\n (ggml_n_dims(op->src[0]) == 2) &&\n op->src[0]->buffer->buft == ggml_backend_cpu_kleidiai_buffer_type() &&... | 2025-09-11T10:45:40 |
denoland/deno | 95e434eb37eccd7a008e230e3f68049ca8eb5db8 | 55621d9ef0d7e9f581c6b2cfe74067a13c872b3f | fix(ext/node): respect abort signal option on `FileHandle.readFile` (#31462)
Towards #29972
Allows
https://github.com/nodejs/node/blob/v24.2.0/test/parallel/test-fs-promises-file-handle-readFile.js
test to pass. | [
{
"path": "ext/node/polyfills/_fs/_fs_readFile.ts",
"patch": "@@ -10,16 +10,37 @@ import {\n TextOptionsArgument,\n } from \"ext:deno_node/_fs/_fs_common.ts\";\n import { Buffer } from \"node:buffer\";\n-import { readAll, readAllSync } from \"ext:deno_io/12_io.js\";\n+import { readAllSync } from \"ext:den... | 2025-12-02T01:13:11 |
huggingface/transformers | ae879f67f892f64f41a70c59b4136721f37fcca0 | 1c4d9982d36dd9a565d695e949907979242f72fc | 🚨 [v5] Delete feature extractors used for vision (#41174)
* bye bye
* remove from docs
* do not use feature extractor here
* fix docs
* do not delete it
* forgot these | [
{
"path": "docs/source/en/main_classes/feature_extractor.md",
"patch": "@@ -16,7 +16,7 @@ rendered properly in your Markdown viewer.\n \n # Feature Extractor\n \n-A feature extractor is in charge of preparing input features for audio or vision models. This includes feature extraction from sequences, e.g., p... | 2025-10-01T11:20:58 |
vuejs/vue | ff551029bf872ad067ac7c5ba7c6311fdde7c674 | cb253d74052ce6ec27bb4961314c7b1bb6d003b9 | wip: fix flow type for weex merge | [
{
"path": "flow/compiler.js",
"patch": "@@ -120,6 +120,9 @@ declare type ASTElement = {\n once?: true;\n onceProcessed?: boolean;\n wrapData?: (code: string) => string;\n+\n+ // weex specific\n+ atom?: boolean;\n }\n \n declare type ASTExpression = {",
"additions": 3,
"deletions": 0,
"la... | 2016-11-07T19:47:14 |
ggml-org/llama.cpp | c0389dba43d50695f9d3f57dd1f1a14cbefc100c | 00681dfc16ba4cebb9c7fbd2cf2656e06a0692a4 | CANN: Disable acl_graph for prefill stage (#15933)
Since the prefill length is not fixed, graphs constructed for the
prefill stage cannot be reused. For this reason, ACL graph
execution is disabled by default during prefill. | [
{
"path": "docs/backend/CANN.md",
"patch": "@@ -318,3 +318,7 @@ Operators are executed using ACL graph execution, rather than in op-by-op (eager\n ### GGML_CANN_GRAPH_CACHE_CAPACITY\n \n Maximum number of compiled CANN graphs kept in the LRU cache, default is 12. When the number of cached graphs exceeds thi... | 2025-09-11T07:59:37 |
denoland/deno | 55621d9ef0d7e9f581c6b2cfe74067a13c872b3f | 1d575591075876fa4ec79e3dbc5030078c3a593f | fix: wpt assert expectation correctly even if the filter has a layer (#30574)
related: #30501
I fixed to assert properly even if the filter has a layer as follows:
```
./tests/wpt/wpt.ts run -- WebCryptoAPI/import_export
``` | [
{
"path": "tests/wpt/wpt.ts",
"patch": "@@ -64,6 +64,24 @@ class TestFilter {\n }\n return false;\n }\n+\n+ shouldKeepWalking(path): boolean {\n+ if (this.filter === undefined || this.filter.length == 0) {\n+ return true;\n+ }\n+ for (const filter of this.filter) {\n+ if (filte... | 2025-12-02T00:51:45 |
vuejs/vue | 550dcee233b3a5a81fdd34f7309e0508901d49c8 | b69b4a4eeff204488c3eb60cac951f9808581e1c | fix coverage | [
{
"path": "src/platforms/web/compiler/modules/style.js",
"patch": "@@ -12,6 +12,7 @@ function transformNode (el: ASTElement, options: CompilerOptions) {\n const warn = options.warn || baseWarn\n const staticStyle = getAndRemoveAttr(el, 'style')\n if (staticStyle) {\n+ /* istanbul ignore if */\n ... | 2016-11-07T21:25:51 |
ggml-org/llama.cpp | 00681dfc16ba4cebb9c7fbd2cf2656e06a0692a4 | 4f658855fa8f2e42b7ed9a5b298fa39a2e39b096 | CUDA: Add `fastdiv` to `k_bin_bcast*`, giving 1-3% E2E performance (#15872)
* Add fastdiv and fastmodulo to k_bin_bcast kernel
* Address review comments
* `prod_` instead of `prod` suffix
* Add test case for `k_bin_bcast_unravel` in CUDA backend | [
{
"path": "ggml/src/ggml-cuda/binbcast.cu",
"patch": "@@ -23,28 +23,44 @@ static __device__ __forceinline__ float op_div(const float a, const float b) {\n return a / b;\n }\n \n-\n-\n-template <float (*bin_op)(const float, const float), typename src0_t, typename src1_t, typename dst_t, typename... src1_... | 2025-09-10T20:04:03 |
denoland/deno | ed684124efd8c1b575d40caed05b858d4b8c1d89 | b38897382e11e75c6808b7efa22f1112baac975d | fix(types): add [Symbol.iterator]() to NodeListOf (fixes #31382) (#31384)
This PR adds missing iterable support to `NodeListOf<TNode>` in the DOM
typings. Without this method, TypeScript raises error TS2488:
```ts
for (const child of div.childNodes) {}
// TS2488: NodeListOf<ChildNode> must have a [Symbol.iterator]() ... | [
{
"path": "cli/tsc/dts/lib.dom.d.ts",
"patch": "@@ -21993,6 +21993,7 @@ interface NodeListOf<TNode extends Node> extends NodeList {\n item(index: number): TNode;\n forEach(callbackfn: (value: TNode, key: number, parent: NodeListOf<TNode>) => void, thisArg?: any): void;\n [index: number]: TNode;\... | 2025-12-02T00:24:36 |
ggml-org/llama.cpp | 9de447d94e1ae9d1a36e5a2e5bf47483352c0d9c | 0f0a3c2851134d49955f3c85afbb0b1bb47c3e07 | ggml-cpu : fix padding in ggml_timestep_embedding (#15917)
This commit fixes the zero padding for odd dimensions in
ggml_compute_forward_timestep_embedding_f32.
The motivation for this is that currently if an odd dimension is used,
the padding check incorrectly uses the dimension value for indexing.
For example, with ... | [
{
"path": "ggml/src/ggml-cpu/ops.cpp",
"patch": "@@ -8598,6 +8598,7 @@ static void ggml_compute_forward_timestep_embedding_f32(\n embed_data[j + half] = sinf(arg);\n }\n if (dim % 2 != 0 && ith == 0) {\n+ embed_data[2 * half] = 0.f;\n embed_data[dim] = 0.f;... | 2025-09-10T15:31:40 |
ollama/ollama | 553fa39fe86ac7a3c69a391cfc97829f7e72dc77 | 3e10f902f5f5521e20b7c7110d9f7a8a30fa11c7 | fix memory leak in create | [
{
"path": "server/images.go",
"patch": "@@ -3,7 +3,6 @@ package server\n import (\n \t\"bytes\"\n \t\"crypto/sha256\"\n-\t\"encoding/hex\"\n \t\"encoding/json\"\n \t\"errors\"\n \t\"fmt\"\n@@ -42,10 +41,9 @@ type Layer struct {\n \tSize int `json:\"size\"`\n }\n \n-type LayerWithBuffer struct {\n+ty... | 2023-07-19T00:14:12 |
vuejs/vue | e960cd104e67e8e410956fa589090fe171382528 | 33cf1134ede0f84f9e50a5f23eea15173e97437e | enable style merge behavior between parent-child components (fix #3997) (#4138)
* merge style between components
* update test case
* update style compiler
* add paren to style binding code
* update background property parsing
* introduce interpolation warning and refactor var to const | [
{
"path": "flow/compiler.js",
"patch": "@@ -106,6 +106,7 @@ declare type ASTElement = {\n \n staticClass?: string;\n classBinding?: string;\n+ staticStyle?: string;\n styleBinding?: string;\n events?: ASTElementHandlers;\n nativeEvents?: ASTElementHandlers;",
"additions": 1,
"deletions": ... | 2016-11-07T21:19:48 |
denoland/deno | b38897382e11e75c6808b7efa22f1112baac975d | 42b6c822548af7995426a9bce26707fa87edbcbf | docs(libs): fix some typos in comment (#31250)
Signed-off-by: geogrego <geogrego@outlook.com> | [
{
"path": "libs/config/testdata/fmt/with_config/subdir/c.md",
"patch": "@@ -5,7 +5,7 @@ unless you specifically enable it, a\n program run with Deno has no file,\n network, or environment access. Access\n to security sensitive functionality\n-requires that permisisons have been\n+requires that permissions h... | 2025-12-01T23:50:24 |
huggingface/transformers | db1cc65c062fb601a8a011e98d7e4d917919ce1d | f22cb1e8689905091acb07e238b670aadde1e4ee | Video processor accepts single frames on cuda (#41218)
* fix
* why was is np if input is in torch | [
{
"path": "src/transformers/video_utils.py",
"patch": "@@ -196,7 +196,9 @@ def make_batched_videos(videos) -> list[Union[np.ndarray, \"torch.Tensor\", \"URL\",\n return convert_pil_frames_to_video([videos])\n # only one frame passed, thus we unsqueeze time dim\n elif is_valid_image(videos):\... | 2025-10-01T08:55:11 |
ggml-org/llama.cpp | 0f0a3c2851134d49955f3c85afbb0b1bb47c3e07 | 33daece86b65607451d0d4378d2d04ba6a20ad55 | metal : make the backend async (#15906)
* metal : make the backend async
ggml-ci
* cont : add comments, extend op offload, clean up
ggml-ci
* metal : fix batch size for MUL_MAT_ID
* metal : remove deprecated ggml_backend_metal_buffer_from_ptr
* metal : create only metal buffers, no wrapping of host memory
ggml-... | [
{
"path": "ggml/include/ggml-metal.h",
"patch": "@@ -43,14 +43,8 @@ GGML_BACKEND_API ggml_backend_t ggml_backend_metal_init(void);\n \n GGML_BACKEND_API bool ggml_backend_is_metal(ggml_backend_t backend);\n \n-GGML_DEPRECATED(\n- GGML_BACKEND_API ggml_backend_buffer_t ggml_backend_metal_buffer_from_p... | 2025-09-10T14:52:35 |
ollama/ollama | 820e581ad8bcc9e7134f87a8e9097ef2f7280877 | d14785738e0192f68fcbc0d64091b59cc2faf702 | web: fix typos and add link to discord | [
{
"path": "web/app/header.tsx",
"patch": "@@ -1,24 +1,24 @@\n-\n const navigation = [\n- { name: 'Github', href: 'https://github.com/jmorganca/ollama' },\n+ { name: 'Discord', href: 'https://discord.gg/MrfB5FbNWN' },\n+ { name: 'GitHub', href: 'https://github.com/jmorganca/ollama' },\n { name: 'Downloa... | 2023-07-19T00:03:40 |
vuejs/vue | 33cf1134ede0f84f9e50a5f23eea15173e97437e | a4fcdbe6731ca4a0ef6a3f94ef06d56cc92636f7 | Update ssr class render (fix #4143) (#4146)
* fix ssr class render
* update test case | [
{
"path": "src/platforms/web/server/modules/class.js",
"patch": "@@ -3,7 +3,8 @@\n import { genClassForVnode } from 'web/util/index'\n \n export default function renderClass (node: VNodeWithData): ?string {\n- if (node.data.class || node.data.staticClass) {\n- return ` class=\"${genClassForVnode(node)}\... | 2016-11-07T16:33:37 |
denoland/deno | 42b6c822548af7995426a9bce26707fa87edbcbf | 3680f8b7993bffe83dda983856def1bb8138e9e6 | fix(node/process): make `process.stdin.isTTY` writable (#31464)
## Summary
In Node.js, `tty.ReadStream` sets `isTTY` as a simple instance property
(`this.isTTY = true`), making it naturally writable. Deno's polyfill
used a getter-only property definition, preventing assignment.
Some npm packages need to override `is... | [
{
"path": "ext/node/polyfills/_process/streams.mjs",
"patch": "@@ -258,12 +258,18 @@ export const initStdin = (warmup = false) => {\n // so that the process can close down.\n stdin.on(\"pause\", () => nextTick(onpause));\n \n+ // Allow users to overwrite isTTY for test isolation and terminal mocking.\n... | 2025-12-01T23:37:23 |
huggingface/transformers | f22cb1e8689905091acb07e238b670aadde1e4ee | 374ded5ea40c9026cf36003c737e07c584dbd63d | fix qwen text config (#41158)
* fix qwen text config
* fix tests
* fix one more test
* address comments | [
{
"path": "src/transformers/models/glm4v/configuration_glm4v.py",
"patch": "@@ -330,7 +330,6 @@ def __init__(\n video_end_token_id=151342,\n **kwargs,\n ):\n- super().__init__(**kwargs)\n if isinstance(vision_config, dict):\n self.vision_config = self.sub_confi... | 2025-09-30T17:23:44 |
ggml-org/llama.cpp | 10d8b2b6b0ac2cae252a80b4daea5da55ab63c2f | 28b5f190ef1dbea5edf82dbc8b4407b721fadd13 | CANN: Add ROPE sin/cos cache for reuse (#15912)
* CANN: Add ROPE sin/cos cache for reuse
Introduce sin/cos caching mechanism in ROPE to avoid redundant
computation across layers. The cache is built on the first layer
per device and reused by subsequent layers if parameters match.
- Added sin_cache / cos_cache pointe... | [
{
"path": "ggml/src/ggml-cann/aclnn_ops.cpp",
"patch": "@@ -2268,26 +2268,30 @@ static void aclnn_index_fill_tensor(ggml_backend_cann_context& ctx,\n * stream, and persistent buffers for rope init/cache.\n * @param dst The destination ggml_tensor whose computation\... | 2025-09-10T10:42:00 |
ollama/ollama | d14785738e0192f68fcbc0d64091b59cc2faf702 | 9e15635c2d891574de72e20ae16a22149f384d81 | README typo fix (#106)
* Fixed typo in README | [
{
"path": "README.md",
"patch": "@@ -59,7 +59,7 @@ Ollama includes a library of open-source, pre-trained models. More models are co\n | Llama2 | 7B | 3.8GB | `ollama pull llama2` |\n | Orca Mini | 3B | 1.9GB | `ollama pull orca` |\n | Vicuna | 7B | 3.8GB | `ol... | 2023-07-18T23:24:57 |
vuejs/vue | b7ab388df325e2552cf1e38b14c8218ec7d3a68a | a2cc6e2b68239460d1c27f9af8b2165594f8ab00 | Fix xhtml namespace typo (#4131) | [
{
"path": "src/platforms/web/util/element.js",
"patch": "@@ -6,7 +6,7 @@ import { makeMap } from 'shared/util'\n export const namespaceMap = {\n svg: 'http://www.w3.org/2000/svg',\n math: 'http://www.w3.org/1998/Math/MathML',\n- xhtml: 'http://www.w3.org/1999/xhtm'\n+ xhtml: 'http://www.w3.org/1999/xh... | 2016-11-05T15:23:57 |
denoland/deno | 3680f8b7993bffe83dda983856def1bb8138e9e6 | 07c3a8bfcd33330208bc7ff2d6d02ca611a0e0ff | fix: clippy::derivable_impls (#31460)
https://rust-lang.github.io/rust-clippy/master/index.html#derivable_impls | [
{
"path": "cli/args/flags.rs",
"patch": "@@ -222,18 +222,13 @@ pub struct CoverageFlags {\n pub r#type: CoverageType,\n }\n \n-#[derive(Clone, Debug, Eq, PartialEq)]\n+#[derive(Clone, Debug, Eq, PartialEq, Default)]\n pub enum DocSourceFileFlag {\n+ #[default]\n Builtin,\n Paths(Vec<String>),\n }\n \... | 2025-12-01T23:21:36 |
ggml-org/llama.cpp | 28b5f190ef1dbea5edf82dbc8b4407b721fadd13 | 86587da03bd78df8f4e7d8b111a0c1d2494d6ed0 | CANN: implement LRU cache for ACL graphs (#15814)
* CANN: implement LRU cache for ACL graphs in CANN backend
- Introduce ggml_cann_graph_lru_cache to store multiple ggml_cann_graph objects.
- Graphs are loaded on demand and evicted using LRU policy when capacity is exceeded.
- Updated push, move_to_front, and clear m... | [
{
"path": "docs/backend/CANN.md",
"patch": "@@ -314,3 +314,7 @@ Converting the matmul weight format from ND to NZ to improve performance. Enable\n ### GGML_CANN_ACL_GRAPH\n \n Operators are executed using ACL graph execution, rather than in op-by-op (eager) mode. Enabled by default.\n+\n+### GGML_CANN_GRAPH... | 2025-09-10T07:29:12 |
huggingface/transformers | 374ded5ea40c9026cf36003c737e07c584dbd63d | 16a141765c3f44a77359482c54d2c6506847e834 | Fix white space in documentation (#41157)
* Fix white space
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
* Revert changes
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
* Fix autodoc
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
---------
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> | [
{
"path": "CONTRIBUTING.md",
"patch": "@@ -278,13 +278,14 @@ are working on it).<br>\n useful to avoid duplicated work, and to differentiate it from PRs ready to be merged.<br>\n ☐ Make sure existing tests pass.<br>\n ☐ If adding a new feature, also add tests for it.<br>\n- - If you are adding a new model... | 2025-09-30T16:41:03 |
vuejs/vue | c67a710b3c4b2630f7e33c61e9fe61b8e732c04c | 6e3e989a90e8685c2cf0c029fa9c657354762b04 | avoid triggering watcher on unchanged default props (fix #4090) (26 seconds ago) | [
{
"path": "src/core/instance/lifecycle.js",
"patch": "@@ -132,6 +132,7 @@ export function lifecycleMixin (Vue: Class<Component>) {\n if (process.env.NODE_ENV !== 'production') {\n observerState.isSettingProps = false\n }\n+ vm.$options.propsData = propsData\n }\n // update l... | 2016-11-05T02:49:30 |
denoland/deno | 07c3a8bfcd33330208bc7ff2d6d02ca611a0e0ff | 99a8dbf1f3320cfa73c1adae24fcc247d496ef8e | fix: update deno_error to 0.7.1 (#31450)
Fixes https://github.com/denoland/deno/issues/31430 | [
{
"path": "Cargo.lock",
"patch": "@@ -2021,9 +2021,9 @@ dependencies = [\n \n [[package]]\n name = \"deno_error\"\n-version = \"0.7.0\"\n+version = \"0.7.1\"\n source = \"registry+https://github.com/rust-lang/crates.io-index\"\n-checksum = \"dde60bd153886964234c5012d3d9caf788287f28d81fb24a884436904101ef10\"... | 2025-12-01T22:45:26 |
ggml-org/llama.cpp | ae355f6f7108540297d8b7f7ae71d20fe610a0b7 | 4f63cd705c7b6f457f36c63fdc053e07f6f3cc6b | vulkan: throw the oom error instead of no memory type found (#15905) | [
{
"path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp",
"patch": "@@ -1937,7 +1937,9 @@ static vk_buffer ggml_vk_create_buffer(vk_device& device, size_t size, const std\n \n vk::PhysicalDeviceMemoryProperties mem_props = device->physical_device.getMemoryProperties();\n \n- for (auto &req_flags : req_flags_... | 2025-09-09T20:26:03 |
huggingface/transformers | 16a141765c3f44a77359482c54d2c6506847e834 | 5d1e8530320099d87302eb216417da6fee07d3ab | [docs] Fix tp_plan (#41205)
remove manual | [
{
"path": "docs/source/en/perf_infer_gpu_multi.md",
"patch": "@@ -45,13 +45,7 @@ This guide shows how to enable tensor parallelism with Transformers and differen\n \n ## Partitioning a model\n \n-Transformers supports tensor parallelism if a model has a `tp_plan`. There are two plans to partition a model.\n... | 2025-09-30T16:27:50 |
vuejs/vue | 6e3e989a90e8685c2cf0c029fa9c657354762b04 | ef0d788fc19eeb3b30f56180e126cf1543f42f94 | log render error instead of throwing | [
{
"path": "src/core/instance/render.js",
"patch": "@@ -65,7 +65,7 @@ export function renderMixin (Vue: Class<Component>) {\n if (config._isServer) {\n throw e\n } else {\n- setTimeout(() => { throw e }, 0)\n+ console.error(e)\n }\n }\n // retur... | 2016-11-05T02:19:45 |
ollama/ollama | aa6714f25ca6ff4dedadccd8e1a661a0fdd56bdc | 7f3a37aed42266111555d7bcbe075146da944c41 | fix typo in `README.md` | [
{
"path": "README.md",
"patch": "@@ -27,7 +27,7 @@ ollama run llama2\n Hello! How can I help you today?\n ```\n \n-### Creating a model\n+### Creating a custom model\n \n Create a `Modelfile`:\n \n@@ -56,7 +56,7 @@ Ollama includes a library of open-source, pre-trained models. More models are co\n \n | Model... | 2023-07-18T21:03:11 |
denoland/deno | efa4da8643c1ada18102bd3eeadb28171f7cdad6 | 84b46ea9a66aad0418436da66af74077b9e4beb1 | fix(ext/web): console.dir respects indent level (#31412)
It looks more natural if you respect the indentation of `console.group`.
`console.dir` on Node.js also respects group indentation, so this
improves Node.js compat.
Test code:
```ts
console.dir("1");
console.group();
console.dir("2");
console.group();
console.d... | [
{
"path": "ext/web/01_console.js",
"patch": "@@ -3172,6 +3172,7 @@ class Console {\n this.#printFunc(\n inspectArgs([obj], {\n ...getConsoleInspectOptions(noColorStdout()),\n+ indentLevel: this.indentLevel,\n ...options,\n }) + \"\\n\",\n 1,",
"additions": 1,... | 2025-11-28T23:36:57 |
ggml-org/llama.cpp | 4f63cd705c7b6f457f36c63fdc053e07f6f3cc6b | 17bc5a815f0bebc1844c99796760cd7df5e9b8d9 | vulkan: Fix OOB accesses in soft_max_back (#15861) | [
{
"path": "ggml/src/ggml-vulkan/ggml-vulkan.cpp",
"patch": "@@ -3387,7 +3387,7 @@ static void ggml_vk_load_shaders(vk_device& device) {\n ggml_vk_create_pipeline(device, device->pipeline_soft_max_f32_wg512, \"soft_max_f32_wg512\", soft_max_f32_len, soft_max_f32_data, \"main\", 4, sizeof(vk_op_soft_max_p... | 2025-09-09T12:41:15 |
huggingface/transformers | 5d1e8530320099d87302eb216417da6fee07d3ab | cecd92849edb85beb5412ef5d8cbe7ee63734d73 | [Trainer] deprecate `num_train_tokens` (#41165)
* dep
* fix
* fix | [
{
"path": "src/transformers/trainer.py",
"patch": "@@ -2296,16 +2296,6 @@ def _inner_training_loop(\n max_steps,\n ) = self.set_initial_training_values(args, train_dataloader, total_train_batch_size)\n \n- num_train_tokens = None\n- if self.args.include_tokens_per_second:\n... | 2025-09-30T15:53:16 |
vuejs/vue | 53964dbad277c81ff0e733b43bee7801eb50fb52 | 51725cff5e2b026088c3afac4c10cbe1e1be3aa7 | fix html parser infinite loop (fix #4127) | [
{
"path": "src/compiler/parser/html-parser.js",
"patch": "@@ -139,7 +139,7 @@ export function parseHTML (html, options) {\n }\n }\n \n- let text, rest\n+ let text, rest, next\n if (textEnd > 0) {\n rest = html.slice(textEnd)\n while (\n@@ -149,7 +149,9 @@ export... | 2016-11-05T01:58:06 |
ollama/ollama | 7f3a37aed42266111555d7bcbe075146da944c41 | 7b0828035547413b0673c15085f57f072edf1d6b | fix typo | [
{
"path": "README.md",
"patch": "@@ -34,7 +34,7 @@ Create a `Modelfile`:\n ```\n FROM llama2\n PROMPT \"\"\"\n-You are super mario from super mario bros. Answer Mario, the assistant, only.\n+You are Mario from Super Mario Bros. Answer as Mario, the assistant, only.\n \n User: {{ .Prompt }}\n Mario:",
"a... | 2023-07-18T20:32:06 |
ggml-org/llama.cpp | a972faebed5fdc4a3d2a844d92d476058c02e02d | 550cf726e133fd0a069d991287fd3a2a3e3e1cbd | CUDA: Add mul_mat_id support for the mmf kernel (#15767)
* CUDA: Add mul_mat_id support the mmf
Add support for mul_mat_id for bs < 16
* Review: use warp_size, fix should_use_mmf condition
* Launch one block per expert, stride along n_expert_used
* templatize mul_mat_id
* Pad shmem to 16 bytes, add helper functio... | [
{
"path": "ggml/src/ggml-cuda/CMakeLists.txt",
"patch": "@@ -44,6 +44,8 @@ if (CUDAToolkit_FOUND)\n list(APPEND GGML_SOURCES_CUDA ${SRCS})\n file(GLOB SRCS \"template-instances/mmq*.cu\")\n list(APPEND GGML_SOURCES_CUDA ${SRCS})\n+ file(GLOB SRCS \"template-instances/mmf*.cu\")\n+ list... | 2025-09-09T06:38:02 |
denoland/deno | 84b46ea9a66aad0418436da66af74077b9e4beb1 | 4c228b455d51162fcb1763422b258202799bc31e | fix(check): move unknown builtin node: module errors to tsc diagnostics (#31449) | [
{
"path": "cli/graph_util.rs",
"patch": "@@ -297,10 +297,10 @@ pub fn resolution_error_for_tsc_diagnostic(\n | NodeJsErrorCode::ERR_UNSUPPORTED_ESM_URL_SCHEME\n | NodeJsErrorCode::ERR_INVALID_FILE_URL_PATH\n | NodeJsErrorCode::ERR_PACKAGE_IMPORT_NOT_DEFINED\n- | NodeJsErrorCode::ERR_U... | 2025-11-28T19:37:08 |
huggingface/transformers | cecd92849edb85beb5412ef5d8cbe7ee63734d73 | 103fa6d235fa34a09c243893b6c85a0b14f23e5e | [v5] Remove train kwargs (#41127)
* rm train kwargs
* fix | [
{
"path": "src/transformers/trainer.py",
"patch": "@@ -2131,7 +2131,6 @@ def train(\n resume_from_checkpoint: Optional[Union[str, bool]] = None,\n trial: Union[\"optuna.Trial\", dict[str, Any], None] = None,\n ignore_keys_for_eval: Optional[list[str]] = None,\n- **kwargs: Any,... | 2025-09-30T15:43:25 |
vuejs/vue | 51725cff5e2b026088c3afac4c10cbe1e1be3aa7 | 5d36e8bc1ba6e25c3094f69490712e9c9113ed1d | fix SVG foreignObject (fix #4122) | [
{
"path": "src/core/vdom/create-element.js",
"patch": "@@ -55,8 +55,9 @@ function _createElement (\n // unknown or unlisted namespaced elements\n // check at runtime because it may get assigned a namespace when its\n // parent normalizes children\n+ const childNs = tag === 'foreignObj... | 2016-11-05T00:51:17 |
ollama/ollama | d1f89778e92e00dc2e5dd2ee5f2bfee407ef0718 | df67a90e644f0c406b2c03d60741e4c19ef6da34 | fix css on smaller screen | [
{
"path": "web/app/download/page.tsx",
"patch": "@@ -29,7 +29,7 @@ export default async function Download() {\n return (\n <>\n <Header />\n- <main className='flex min-h-screen max-w-6xl flex-col p-20 lg:p-32 items-center mx-auto'>\n+ <main className='flex min-h-screen max-w-6xl flex-c... | 2023-07-18T20:17:42 |
ggml-org/llama.cpp | 550cf726e133fd0a069d991287fd3a2a3e3e1cbd | c252ce67c4b99f056eeb18d42a289e28fee03475 | CUDA: fix GET_ROWS for large tensors (#15882) | [
{
"path": "ggml/src/ggml-cuda/getrows.cu",
"patch": "@@ -2,67 +2,69 @@\n #include \"dequantize.cuh\"\n #include \"convert.cuh\"\n \n-#define MAX_GRIDDIM_Y 65535\n-\n template<int qk, int qr, dequantize_kernel_t dequantize_kernel, typename dst_t>\n static __global__ void k_get_rows(\n const void * __... | 2025-09-09T06:11:01 |
huggingface/transformers | e99dee6470ef276d814138b087cf0541d1fa63ae | dded9fd1122a504be7b6be254f39f6cac220ce3f | Remove old sagemaker api support (#41161)
* fix
* fix | [
{
"path": "src/transformers/trainer.py",
"patch": "@@ -208,13 +208,8 @@\n \n if is_sagemaker_mp_enabled():\n import smdistributed.modelparallel.torch as smp\n- from smdistributed.modelparallel import __version__ as SMP_VERSION\n-\n- IS_SAGEMAKER_MP_POST_1_10 = version.parse(SMP_VERSION) >= version... | 2025-09-30T15:41:52 |
denoland/deno | 4c228b455d51162fcb1763422b258202799bc31e | ef3192d8797d44d7c2a27e869809f587d67832bc | fix(ext/node): reimplement `setImmediate` API (#30328)
Closes https://github.com/denoland/deno/issues/28016 | [
{
"path": "Cargo.lock",
"patch": "@@ -1887,9 +1887,9 @@ dependencies = [\n \n [[package]]\n name = \"deno_core\"\n-version = \"0.370.0\"\n+version = \"0.371.0\"\n source = \"registry+https://github.com/rust-lang/crates.io-index\"\n-checksum = \"03593764555f24a3287b321c156304e8d142105631258f1fabdeac07013bb4a... | 2025-11-28T10:05:41 |
vuejs/vue | 5d36e8bc1ba6e25c3094f69490712e9c9113ed1d | 0973342e5cadaa68c21535cb9e62f27fd5493e2c | fix IE conditional comments (fix #4125) | [
{
"path": "src/compiler/parser/html-parser.js",
"patch": "@@ -37,6 +37,8 @@ const startTagOpen = new RegExp('^<' + qnameCapture)\n const startTagClose = /^\\s*(\\/?)>/\n const endTag = new RegExp('^<\\\\/' + qnameCapture + '[^>]*>')\n const doctype = /^<!DOCTYPE [^>]+>/i\n+const comment = /^<!--/\n+const co... | 2016-11-04T23:48:11 |
ollama/ollama | df67a90e644f0c406b2c03d60741e4c19ef6da34 | 576ae644de669e36606ee32dc0e0963477a14403 | fix css | [
{
"path": "web/app/download/signup.tsx",
"patch": "@@ -28,7 +28,7 @@ export default function Signup() {\n \n return false\n }}\n- className='flex self-stretch flex-col gap-3 h-32 md:mx-[10rem] lg:mx-[18rem]'\n+ className='flex self-stretch flex-col gap-3 h-32 md:mx-40 lg:mx-72'\n ... | 2023-07-18T20:02:45 |
ggml-org/llama.cpp | 70cd37dbbebdb7a2f84f08207f18eabb0b291a55 | acc1b008cfd95e63d5f99a370dbffb98e5a99d2c | requirements : update transformers/torch for Embedding Gemma (#15828)
* requirements : update transformers/torch for Embedding Gemma
This commit updates the requirements to support converting
Embedding Gemma 300m models.
The motivation for this change is that during development I had a local
copy of the transformers... | [
{
"path": "requirements/requirements-convert_hf_to_gguf.txt",
"patch": "@@ -2,7 +2,9 @@ mistral-common>=1.8.3\n \n -r ./requirements-convert_legacy_llama.txt\n --extra-index-url https://download.pytorch.org/whl/cpu\n-torch~=2.4.0; platform_machine != \"s390x\"\n+\n+## Embedding Gemma requires PyTorch 2.6.0 ... | 2025-09-09T04:06:52 |
huggingface/transformers | 6fb6117abebbc83daa2edc4d364425f022f21b66 | 5bdb70450d40f511c0959e632fb3db5ee933a1f1 | Revert "Fix DeepSpeed mixed precision precedence over Accelerate defaults" (#41124)
* Revert "Fix DeepSpeed mixed precision precedence over Accelerate defaults (#3…"
This reverts commit df67cd35f0ca1a1cbf7147b2576db31b16200cf4.
* fix | [
{
"path": "src/transformers/integrations/deepspeed.py",
"patch": "@@ -130,58 +130,11 @@ def fill_match(self, ds_key_long, hf_val, hf_key=None, must_match=True):\n \n fill_only = partialmethod(fill_match, must_match=False)\n \n- def override_training_args_from_deepspeed(self, args):\n- \"\"\"\n... | 2025-09-30T15:37:42 |
vuejs/vue | d0afcd3cf9ad572621676ef02005d226cb4ac7c4 | fa16b129ca1a2c23211ee545e129cae4eaff877d | fix domProps unset for v-html (fix #4107) | [
{
"path": "src/core/vdom/patch.js",
"patch": "@@ -78,7 +78,10 @@ export function createPatchFunction (backend) {\n \n function removeElement (el) {\n const parent = nodeOps.parentNode(el)\n- nodeOps.removeChild(parent, el)\n+ // element may have already been removed due to v-html\n+ if (paren... | 2016-11-04T20:22:49 |
huggingface/transformers | 5bdb70450d40f511c0959e632fb3db5ee933a1f1 | a61fc6a0b985548c681df89c15f8053dafe322bf | Fix sliding window attn mask (#41228)
* Fix sliding window attn mask
* Clearer test
* Apply style fixes
* If Picasso made ascii drawings he would have made this
---------
Co-authored-by: github-actions[bot] <github-actions[bot]@users.noreply.github.com> | [
{
"path": "src/transformers/generation/continuous_batching/continuous_api.py",
"patch": "@@ -42,7 +42,56 @@ def build_attention_mask(\n ) -> None:\n \"\"\"Builds an attention mask inplace using the cumulative seqlens of the query and key. If given a sliding window, it\n will also apply a sliding win... | 2025-09-30T15:22:53 |
vuejs/vue | e5f23d9fa020e392c70914e61cd4bd8f6b9bc120 | 240df147f11824db5811d23c8704225aa586b96b | fix component attrs/domProps merging in SSR | [
{
"path": "src/platforms/web/server/modules/attrs.js",
"patch": "@@ -8,14 +8,28 @@ import {\n \n export default function renderAttrs (node: VNodeWithData): string {\n let res = ''\n- if (node.data.attrs) {\n- res += render(node.data.attrs)\n+ if (node.data.attrs || node.parent) {\n+ res += render(... | 2016-11-04T16:53:15 |
ollama/ollama | f20426a7681c068eff841921583c9c867104506d | a9cc270b4da9bac2b2ffbc05c809b49e56649816 | fix mkdir blob path | [
{
"path": "cmd/cmd.go",
"patch": "@@ -9,7 +9,6 @@ import (\n \t\"net\"\n \t\"net/http\"\n \t\"os\"\n-\t\"path/filepath\"\n \t\"strings\"\n \t\"time\"\n \n@@ -24,15 +23,6 @@ import (\n \t\"github.com/jmorganca/ollama/server\"\n )\n \n-func cacheDir() string {\n-\thome, err := os.UserHomeDir()\n-\tif err != n... | 2023-07-18T18:24:19 |
huggingface/transformers | a61fc6a0b985548c681df89c15f8053dafe322bf | 919a4845fb4f510c73e911c4ee05802fbbebf64f | Fix typing of train_args (#41142)
* Fix typing
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
* Fix fsdp typing
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com>
---------
Signed-off-by: Yuanyuan Chen <cyyever@outlook.com> | [
{
"path": "src/transformers/training_args.py",
"patch": "@@ -476,7 +476,7 @@ class TrainingArguments:\n When resuming training, whether or not to skip the epochs and batches to get the data loading at the same\n stage as in the previous training. If set to `True`, the training will b... | 2025-09-30T14:28:02 |
ollama/ollama | c7dd52271c5ab1d5182549d2a0e8d2340ad68bc0 | 53d0052c6c588cfe91a7cd0622ab4800ccf6f6ad | remove debugging messages | [
{
"path": "server/images.go",
"patch": "@@ -821,13 +821,11 @@ func downloadBlob(registryURL, repoName, digest string, username, password strin\n \tfor {\n \t\tfn(fmt.Sprintf(\"Downloading %s\", digest), digest, int(total), int(completed), float64(completed)/float64(total))\n \t\tif completed >= total {\n-\t... | 2023-07-17T19:39:55 |
denoland/deno | ef3192d8797d44d7c2a27e869809f587d67832bc | 4876b41d59d79bbed3cbf11e010d20c62770dac4 | fix(node/timers): ensure active timers entry is deleted on `Timeout.prototype.refresh` (#31436)
Closes https://github.com/denoland/deno/issues/31435 | [
{
"path": "ext/node/polyfills/internal/timers.mjs",
"patch": "@@ -5,6 +5,7 @@ import { primordials } from \"ext:core/mod.js\";\n const {\n FunctionPrototypeBind,\n MapPrototypeDelete,\n+ MapPrototypeGet,\n MapPrototypeSet,\n NumberIsFinite,\n SafeArrayIterator,\n@@ -33,6 +34,7 @@ export { kTimerI... | 2025-11-27T19:03:27 |
vuejs/vue | 240df147f11824db5811d23c8704225aa586b96b | c23c5c5d7011d29764fccca4f88155d1c5cfbbf8 | Generate style on custom component in SSR (fix #4055) (#4076)
* fix #4055, generate style on custom component
* add test for custom component style
* add synthetic data for module processing | [
{
"path": "src/platforms/web/server/modules/style.js",
"patch": "@@ -2,24 +2,43 @@\n \n import { hyphenate, toObject } from 'shared/util'\n \n-export default function renderStyle (node: VNodeWithData): ?string {\n+function concatStyleString (former: string, latter: string) {\n+ if (former === '' || latter ... | 2016-11-04T13:38:52 |
ggml-org/llama.cpp | 88021565f08e0b7c4e07ac089a15ec16fae9166c | 56920f56651908d5cce7a310dabf54ac4f6fbb7f | chat : Deepseek V3.1 reasoning and tool calling support (OpenAI Style) (#15533)
* Add DeepSeek V3.1 thinking mode support
- Added COMMON_CHAT_FORMAT_DEEPSEEK_V3_1 enum value
- Created common_chat_params_init_deepseek_v3_1() function (currently uses R1 implementation)
- Created common_chat_parse_deepseek_v3_1() functi... | [
{
"path": "common/chat.cpp",
"patch": "@@ -631,6 +631,7 @@ const char * common_chat_format_name(common_chat_format format) {\n case COMMON_CHAT_FORMAT_FIREFUNCTION_V2: return \"FireFunction v2\";\n case COMMON_CHAT_FORMAT_FUNCTIONARY_V3_2: return \"Functionary v3.2\";\n case COMMON_C... | 2025-09-08T14:59:48 |
vuejs/vue | c23c5c5d7011d29764fccca4f88155d1c5cfbbf8 | 4078ce9c58830fecff095ab96dc41693377794dd | keep consistency in dev and prod env (#4093)
* keep consistency in dev and prod env
* Update extend.js
* delete name=null
* fixup
* Update name.spec.js | [
{
"path": "src/core/global-api/extend.js",
"patch": "@@ -22,14 +22,13 @@ export function initExtend (Vue: GlobalAPI) {\n if (isFirstExtend && extendOptions._Ctor) {\n return extendOptions._Ctor\n }\n- let name = extendOptions.name || Super.options.name\n+ const name = extendOptions.name ... | 2016-11-04T13:35:10 |
denoland/deno | 4876b41d59d79bbed3cbf11e010d20c62770dac4 | 24a0209fa1076586a7e76685e3d27e3d41d47246 | fix: upgrade to swc_ecma_parser 27 (#31427) | [
{
"path": ".dprint.json",
"patch": "@@ -83,7 +83,7 @@\n \"tests/specs/run/error_syntax_empty_trailing_line/error_syntax_empty_trailing_line.mjs\"\n ],\n \"plugins\": [\n- \"https://plugins.dprint.dev/typescript-0.95.11.wasm\",\n+ \"https://plugins.dprint.dev/typescript-0.95.13.wasm\",\n \"... | 2025-11-27T18:07:50 |
huggingface/transformers | 52f5eca7c96dd21618c2481e23f5f4f3a6a756eb | a80f05dfcb23e1de981ce1eb48f278a8c048b3e5 | :rotating_light: [`v5`] Remove headmasking (#41076)
* first attempt at removing
* copies
* last bits in core
* quick fixes
* tests purge
* docs and examples
* some fixes
* more
* another round of cleanups
* fix
* fix a bunch of models
* fix dummy bert
* fix
* fix new model
* fix signature change
* fix
... | [
{
"path": "docs/source/en/model_doc/biogpt.md",
"patch": "@@ -121,7 +121,6 @@ print(output)\n \n - Pad inputs on the right because BioGPT uses absolute position embeddings.\n - BioGPT can reuse previously computed key-value attention pairs. Access this feature with the [past_key_values](https://huggingface.... | 2025-09-30T14:04:57 |
ggml-org/llama.cpp | b0d52998b962bd2681c34bf52af993af79f178b8 | f28d4f4ac963f182ea9d0fe9e269f3f5f3782aaf | cuda : fix supports_op condition for get_rows when number of blocks is too large (#15868)
* cuda : fix supports_op condition for get_rows when src1->ne2 > 1
ggml-ci
* ggml : add comment about ggml_get_rows
ggml-ci
* cuda : add FIXME [no ci]
* cuda : update support condition
ggml-ci | [
{
"path": "ggml/include/ggml.h",
"patch": "@@ -1529,7 +1529,11 @@ extern \"C\" {\n struct ggml_context * ctx,\n struct ggml_tensor * a);\n \n- // supports 3D: a->ne[2] == b->ne[1]\n+ // supports 4D a:\n+ // a [n_embd, ne1, ne2, ne3]\n+ // b I32 [n_rows, ne2, ne3, 1]\... | 2025-09-08T10:56:51 |
ollama/ollama | bcb612a30a6df608cfcb3005c5b3c5ceb9dc1195 | 59fa93cdd4bda4cdf66ac58d729ffc94e3c77c4b | fix file paths for windows | [
{
"path": "server/images.go",
"patch": "@@ -66,7 +66,7 @@ func GetManifest(name string) (*ManifestV2, error) {\n \t\treturn nil, err\n \t}\n \n-\tfp := filepath.Join(home, \".ollama/models/manifests\", name)\n+\tfp := filepath.Join(home, \".ollama\", \"models\", \"manifests\", name)\n \t_, err = os.Stat(fp)... | 2023-07-17T17:45:12 |
vuejs/vue | 4078ce9c58830fecff095ab96dc41693377794dd | 35f145cfc10b6101c1b0c10d348520d367031619 | fix #4041, warn overriding Vue's internal methods (#4111)
* fix #4041, warn overriding Vue's internal methods
* prefer concise warning message | [
{
"path": "src/core/instance/state.js",
"patch": "@@ -21,6 +21,8 @@ import {\n noop\n } from '../util/index'\n \n+import BuiltinVue from '../index'\n+\n export function initState (vm: Component) {\n vm._watchers = []\n initProps(vm)\n@@ -143,12 +145,16 @@ function initMethods (vm: Component) {\n if ... | 2016-11-04T11:44:47 |
huggingface/transformers | a80f05dfcb23e1de981ce1eb48f278a8c048b3e5 | 1f1e93e09537ff148956cb602c85d319e972f190 | [generate] cache missing custom generate file (#41216)
* cache missing custom generate file
* make fixup | [
{
"path": "src/transformers/generation/utils.py",
"patch": "@@ -22,7 +22,6 @@\n \n import torch\n import torch.distributed as dist\n-from huggingface_hub import file_exists\n from packaging import version\n from torch import nn\n \n@@ -392,23 +391,20 @@ def load_custom_generate(\n Returns:\n ... | 2025-09-30T13:32:24 |
ggml-org/llama.cpp | f28d4f4ac963f182ea9d0fe9e269f3f5f3782aaf | 9fcb29f22f5c33c04c7f0daebb24057899d67a1a | metal : refactor + optimize (#15857)
* metal : refactor
ggml-ci
* cont : refactor FA-vec kernel
* cont : print metal library load time
* minor : warn to debug + bettern kernel names
ggml-ci
* metal : optimize mul_mv q8_0
ggml-ci
* metal : simplify FA pipeline creation functions
ggml-ci
* metal : improve nami... | [
{
"path": "ggml/src/ggml-metal/ggml-metal-impl.h",
"patch": "@@ -20,8 +20,8 @@\n #define N_R0_Q5_1 4\n #define N_SG_Q5_1 2\n \n-#define N_R0_Q8_0 4\n-#define N_SG_Q8_0 2\n+#define N_R0_Q8_0 2\n+#define N_SG_Q8_0 4\n \n #define N_R0_MXFP4 2\n #define N_SG_MXFP4 2\n@@ -68,6 +68,11 @@\n #define N_R0_IQ4_XS 2\n... | 2025-09-08T10:34:56 |
vuejs/vue | 35f145cfc10b6101c1b0c10d348520d367031619 | bc455352a3dd95bc7c5789feb4d7e969427351d4 | Update vue.d.ts (#4105)
fix typo. | [
{
"path": "types/vue.d.ts",
"patch": "@@ -7,7 +7,7 @@ import {\n WatchHandler,\n DirectiveOptions,\n DirectiveFunction\n-} from \"./options.d\";\n+} from \"./options\";\n import { VNode, VNodeData, VNodeChildren } from \"./vnode\";\n import { PluginFunction, PluginObject } from \"./plugin\";\n ",
... | 2016-11-04T00:37:20 |
denoland/deno | faf95058149485560fafc0ba977db331e1874b38 | 3e22a737edc435d04f7f1233f3f0d75d94ae23a7 | fix(node): support advanced serialization in IPC (#31380)
Fixes #31354. | [
{
"path": "Cargo.lock",
"patch": "@@ -2474,6 +2474,7 @@ dependencies = [\n \"k256\",\n \"libc\",\n \"libz-sys\",\n+ \"log\",\n \"md-5\",\n \"md4\",\n \"nix 0.27.1\",",
"additions": 1,
"deletions": 0,
"language": "Unknown"
},
{
"path": "Cargo.toml",
"patch": "@@ -201,7 +201,7 @@... | 2025-11-26T23:15:32 |
ollama/ollama | 2fb52261adb031039fe927350a257da84b9a5854 | 6fdea03049eb433a7cc1002ec85438707e70341f | basic distribution w/ push/pull (#78)
* basic distribution w/ push/pull
* add the parser
* add create, pull, and push
* changes to the parser, FROM line, and fix commands
* mkdirp new manifest directories
* make `blobs` directory if it does not exist
* fix go warnings
* add progressbar for model p... | [
{
"path": "api/client.go",
"patch": "@@ -116,3 +116,29 @@ func (c *Client) Pull(ctx context.Context, req *PullRequest, fn PullProgressFunc\n \t\treturn fn(resp)\n \t})\n }\n+\n+type PushProgressFunc func(PushProgress) error\n+\n+func (c *Client) Push(ctx context.Context, req *PushRequest, fn PushProgressFun... | 2023-07-17T00:02:22 |
vuejs/vue | d9efc6a92b54547869f20040a47fd0bf07024b9a | 887ec90d1484599398ffdd17df9f088d6cc6800f | clone components hash to avoid webpack 2 immutable export (fix #4062) | [
{
"path": "src/core/util/options.js",
"patch": "@@ -200,6 +200,7 @@ const defaultStrat = function (parentVal: any, childVal: any): any {\n function normalizeComponents (options: Object) {\n if (options.components) {\n const components = options.components\n+ const normalized = options.components = ... | 2016-11-03T20:23:05 |
ggml-org/llama.cpp | 9fcb29f22f5c33c04c7f0daebb24057899d67a1a | 5ef22d281de9c5eaaf616874bc490b89241128cb | ggml: allow casting between f32 and i32 (#15783)
* ggml: allow casting between f32 and i32
* fix cuda
* add vulkan
* fix CPU non-cont
* add non-cont test case
* add note
* extend test number range
* correct note
* add cont version for vulkan | [
{
"path": "ggml/include/ggml-cpu.h",
"patch": "@@ -134,6 +134,7 @@ extern \"C\" {\n GGML_BACKEND_API ggml_backend_reg_t ggml_backend_cpu_reg(void);\n \n GGML_BACKEND_API void ggml_cpu_fp32_to_fp32(const float *, float *, int64_t);\n+ GGML_BACKEND_API void ggml_cpu_fp32_to_i32 (const float *... | 2025-09-08T10:33:01 |
huggingface/transformers | 1f1e93e09537ff148956cb602c85d319e972f190 | 2a596f5b2f3d9c55b8ded806a9b6b8b3312062df | Align pull request template to bug report template (#41220)
The only difference is that I don't users to https://discuss.huggingface.co/ for hub issues. | [
{
"path": ".github/PULL_REQUEST_TEMPLATE.md",
"patch": "@@ -39,41 +39,40 @@ members/contributors who may be interested in your PR.\n \n Models:\n \n-- text models: @ArthurZucker\n-- vision models: @amyeroberts, @qubvel\n-- speech models: @eustlb\n+- text models: @ArthurZucker @Cyrilvallez\n+- vision models:... | 2025-09-30T12:25:41 |
denoland/deno | d704ca228a872a31c82c5de9f852916c8f07a981 | 109196ca03ff1b02036bac7d7e3886945060d415 | fix(bundle): avoid name clash in hack (#31409)
One of the issues described in #31407. | [
{
"path": "cli/tools/bundle/mod.rs",
"patch": "@@ -663,16 +663,16 @@ fn replace_require_shim(contents: &str, minified: bool) -> String {\n );\n re.replace(contents, |c: ®ex::Captures<'_>| {\n let var_name = c.get(1).unwrap().as_str();\n- format!(\"import{{createRequire}} from \\\"node:... | 2025-11-26T10:30:59 |
vuejs/vue | 887ec90d1484599398ffdd17df9f088d6cc6800f | 5a4c1d7f70f96bb1ebf47c10c0f420d2ed9d5584 | fix RenderContext (#4099) | [
{
"path": "types/options.d.ts",
"patch": "@@ -55,7 +55,7 @@ export interface FunctionalComponentOptions {\n export interface RenderContext {\n props: any;\n children: VNode[];\n- slots: any;\n+ slots(): any;\n data: VNodeData;\n parent: Vue;\n }",
"additions": 1,
"deletions": 1,
"langu... | 2016-11-03T17:07:07 |
ggml-org/llama.cpp | 233d773d02c37982badddf3994e9953a175f34da | a885dcff11a7b73f9377812d6151f6b15d307de0 | convert : force setting sliding_window from original config (#15867)
* convert : force setting sliding_window from original config
This commit modifies the set_gguf_parameters method for EmbeddingGemma
so that it reads the sliding_window parameter from the original model
config.json and uses that value.
The motivati... | [
{
"path": "convert_hf_to_gguf.py",
"patch": "@@ -5128,6 +5128,20 @@ class EmbeddingGemma(Gemma3Model):\n \n def set_gguf_parameters(self):\n super().set_gguf_parameters()\n+\n+ # Override the sliding window size as it gets adjusted by the Gemma3TextConfig\n+ # constructor. We want ... | 2025-09-08T07:44:34 |
huggingface/transformers | 3edd8048b01c51f1d1e721baa991cad5f77d6625 | 59035fd0e1876f9e526488b61fe43ff8829059f6 | Trainer: Pass `num_items_in_batch` to `compute_loss` in `prediction_step` (#41183)
* Add num_items_in_batch computation to predict_step.
* address comments.
* Fix test cases.
* fixup
---------
Co-authored-by: Marc Sun <57196510+SunMarc@users.noreply.github.com> | [
{
"path": "src/transformers/trainer.py",
"patch": "@@ -4844,7 +4844,10 @@ def prediction_step(\n else:\n if has_labels or loss_without_labels:\n with self.compute_loss_context_manager():\n- loss, outputs = self.compute_loss(model, inputs... | 2025-09-30T09:45:17 |
denoland/deno | 109196ca03ff1b02036bac7d7e3886945060d415 | 48546aa4a9f42decaa11471904ab0ece5ce2d644 | fix(bundle): do not error on failing to clean up esbuild dir (#31408)
Fixes https://github.com/denoland/deno/issues/31406
This is just to save some space on the user's device, no need to hard
error if it fails. | [
{
"path": "cli/tools/bundle/esbuild.rs",
"patch": "@@ -110,9 +110,13 @@ pub async fn ensure_esbuild(\n })?;\n \n if !existed {\n- std::fs::remove_dir_all(&package_folder).with_context(|| {\n- format!(\"failed to remove directory {}\", package_folder.display())\n- })?;\n+ let _ ... | 2025-11-26T10:24:25 |
ollama/ollama | 40c9dc0a3191dbb85f6dbfbdd1a1952b5e8073d0 | 0142660bd4ef778860d47dfaf7a6f51ff82bb348 | fix multibyte responses | [
{
"path": "llama/llama.go",
"patch": "@@ -78,12 +78,14 @@ llama_token llama_sample(\n */\n import \"C\"\n import (\n+\t\"bytes\"\n \t\"errors\"\n \t\"fmt\"\n \t\"io\"\n \t\"os\"\n \t\"strings\"\n \t\"time\"\n+\t\"unicode/utf8\"\n \t\"unsafe\"\n \n \t\"github.com/jmorganca/ollama/api\"\n@@ -204,6 +206,7 @@ f... | 2023-07-15T01:30:32 |
ggml-org/llama.cpp | a885dcff11a7b73f9377812d6151f6b15d307de0 | 663027fd5490438ce9c27ea866a560e1e268d11f | batched-bench : fix llama_synchronize usage during prompt processing (#15835)
ggml-ci | [
{
"path": "tools/batched-bench/batched-bench.cpp",
"patch": "@@ -71,7 +71,7 @@ int main(int argc, char ** argv) {\n llama_batch batch = llama_batch_init(n_kv_max, 0, 1);\n \n // decode in batches of ctx_params.n_batch tokens\n- auto decode_helper = [](llama_context * ctx, llama_batch & batch, int... | 2025-09-08T07:27:07 |
vuejs/vue | e2a361a052dfdfb3f531e9a8e26b12d48309f6b9 | ec824be88e9bc71b31e5c4a43f80d921674dca66 | forgivingly handle < inside template plain text (fix #4012) | [
{
"path": "src/compiler/parser/html-parser.js",
"patch": "@@ -91,7 +91,7 @@ export function parseHTML (html, options) {\n last = html\n // Make sure we're not in a script or style element\n if (!lastTag || !isSpecialTag(lastTag, options.sfc, stack)) {\n- const textEnd = html.indexOf('<')\n+... | 2016-11-03T04:53:49 |
huggingface/transformers | d97397787e4507127d6e56ed1642d1ac7e13b569 | 06c04e085154bb19ea16aac80ae02537fe3b2fd2 | Wait for main process in _save_checkpoint to ensure best checkpoint exists (#40923)
* Update trainer.py
* fix
* fix format
* move barrier, delete redundant | [
{
"path": "src/transformers/trainer.py",
"patch": "@@ -2765,14 +2765,6 @@ def _inner_training_loop(\n \n logger.info(\"\\n\\nTraining completed. Do not forget to share your model on huggingface.co/models =)\\n\\n\")\n if args.load_best_model_at_end and self.state.best_model_checkpoint is not... | 2025-09-30T09:41:03 |
Subsets and Splits
Assembly Language GitHub Issues
Retrieves a sample of assembly-language related commits with their details, but doesn't provide meaningful analysis or patterns beyond basic filtering.
Swift Compiler Issues Analysis
Retrieves all training data for the Swift programming language repository, providing basic filtering but offering limited analytical insight beyond identifying relevant code examples.